.. module:: mpl_toolkits.axes_grid1

.. redirect-from:: /api/toolkits/axes_grid

``mpl_toolkits.axes_grid1``
===========================

:mod:`mpl_toolkits.axes_grid1` provides a framework of helper classes to adjust
the positioning of multiple fixed-aspect Axes (e.g., displaying images).  It
can be contrasted with the ``aspect`` property of Matplotlib Axes, which
adjusts the position of a single Axes.

See :ref:`axes_grid1_users-guide-index` for a guide on the usage of axes_grid1.

.. figure:: ../../gallery/axes_grid1/images/sphx_glr_demo_axes_grid_001.png
   :target: ../../gallery/axes_grid1/demo_axes_grid.html
   :align: center
   :scale: 50

.. note::

   This module contains classes and function that were formerly part of the
   ``mpl_toolkits.axes_grid`` module that was removed in 3.6. Additional
   classes from that older module may also be found in
   `mpl_toolkits.axisartist`.

.. currentmodule:: mpl_toolkits

**The submodules of the axes_grid1 API are:**

.. autosummary::
   :toctree: ../_as_gen
   :template: automodule.rst

   axes_grid1.anchored_artists
   axes_grid1.axes_divider
   axes_grid1.axes_grid
   axes_grid1.axes_rgb
   axes_grid1.axes_size
   axes_grid1.inset_locator
   axes_grid1.mpl_axes
   axes_grid1.parasite_axes
